@@ -65,7 +65,7 @@ class LearningMachine(object):
                convergence=0.01,nconvergence=3,
                accCriteria=0.95,lossCriteria=1000.0,lossTole=1.0,accTole=0.005,
                accMax=0.96,accInc=1.0,mdInc=1.2,resetAcc=5,
-               learnWay=5,
+               learnWay=5,FreePairs=None,
                FreeAtoms=None,FirstAtom=None,
                rodic=None,
                rmin=0.6,rmax=1.3,angmax=15.0,
@@ -145,10 +145,15 @@ class LearningMachine(object):
       self.MessageFunction= MessageFunction
       self.writelib     = writelib
       self.freeatoms    = FreeAtoms
+      self.freepairs    = FreePairs
       self.a            = AtomDance(poscar=self.initConfig,nn=self.nn,
                                     rmin=self.rmin-0.05,rmax=self.rmax,
                                     FirstAtom=FirstAtom,freeatoms=self.freeatoms)
-      self.a.get_freebond(freeatoms=self.freeatoms)
+      if self.freepairs is None:
+         self.a.get_freebond(freeatoms=self.freeatoms)
+      else:
+      	 self.a.freebonds = self.freepairs
+      	 
       self.natom        = self.a.natom
       self.atom_name    = self.a.atom_name
       self.get_ro(rodic)
@@ -215,6 +220,7 @@ class LearningMachine(object):
          ms        = 0
 
       self.learnpair = None
+      groupi,groupj  = None,None
       self.save_config()
       converg        = False
       nconvergence   = 0
@@ -249,7 +255,7 @@ class LearningMachine(object):
              if momsteps >= mom_step:
                 momsteps  = 0
                 if learnWay == 4:
-                   atoms,self.learnpair = self.a.bond_momenta(atoms)
+                   atoms,self.learnpair,groupi,groupj = self.a.bond_momenta(atoms)
                    if self.learnpair is None:
                       learnWay = 3
                 elif learnWay == 5:
@@ -336,7 +342,8 @@ class LearningMachine(object):
           if self.UseZmat:
              if not zmatopt is None:
                 optlog = self.a.get_optimal_zv(atoms,zmatopt,self.initConfig)
-             unreasonable_zv,u_zvlo,u_zvhi = self.a.get_zmat_info(zmats)
+             if mdsteps>10:
+                unreasonable_zv,u_zvlo,u_zvhi = self.a.get_zmat_info(zmats)
 
           if mdsteps<10: mdsteps = 10
           zmats   = None
@@ -357,10 +364,11 @@ class LearningMachine(object):
                                                     zvlo=u_zvlo,zvhi=u_zvhi,traj='md.traj')
              else:
                 e_gmd,mdsteps,Deformed,zmats,zmat_variable,zvlo,zvhi = self.mlmd(cwd,run_dir,atoms, 10000,
-                                                iter_,learnWay,beta=self.beta,learnpair=self.learnpair) 
-                if self.UseZmat and mdsteps<=2:
-                   mdsteps= 7
-                   images,relaxlog = self.a.zmat_relax(atoms=atoms,nbin=20,relax_step=mdsteps,traj='md.traj')
+                                                iter_,learnWay,beta=self.beta,learnpair=self.learnpair,
+                                                groupi=groupi,groupj=groupj) 
+                # if self.UseZmat and mdsteps<=2:
+                #    mdsteps= 7
+                #    images,relaxlog = self.a.zmat_relax(atoms=atoms,nbin=20,relax_step=mdsteps,traj='md.traj')
              if not images is None:
                 Deformed,zmat,zmat_variable,zvlo,zvhi = check_zmat(atoms=images[-1],rmin=self.rmin,
                                        rmax=self.rmax,angmax=self.angmax,zmat_id=self.a.zmat_id,
@@ -402,14 +410,17 @@ class LearningMachine(object):
           else:
              nconvergence  = 0
           if nconvergence > self.nconvergence:
-             print('-  Convergence occured.')
-             send_msg('-  Convergence occured.')
+             print('-  Learning is Convergenced.')
+             send_msg('-  Learning is Convergenced.')
              return diff
 
           if iter_>self.maxiter:
              print('-  Max iteration reached,the loss %7.4f and accuracy %7.4f.' %(loss,accu))
              send_msg('-  Max iteration reached, the loss %7.4f and accuracy %7.4f.' %(loss,accu))
              return diff
+          elif loss==-1:
+             send_msg('-  Some error occurred!')
+             return diff
           iter_ += 1
 
   def learninglog(self,i,loss,accu,mdsteps,eirff,edft,dEmax,d2Emax,learnWay,Deformed,
@@ -465,7 +476,8 @@ class LearningMachine(object):
       chdir(cwd)
       return eaimd,emlmd,dEmax,d2Emax
 
-  def mlmd(self,cwd,run_dir,atoms,Tmax,Iter,learnWay,learnpair=None,beta=None):        
+  def mlmd(self,cwd,run_dir,atoms,Tmax,Iter,learnWay,learnpair=None,beta=None,
+           groupi=None,groupj=None):        
       ''' run classic MD to test training results '''
       mdstep = max(int(self.md_step/5),2) if learnWay==2 else self.md_step
       irmd = IRMD(atoms=atoms,label=self.label,Iter=Iter,initT=self.T,
@@ -473,8 +485,8 @@ class LearningMachine(object):
                   ro=self.ro,rmin=self.rmin,rmax=self.rmax,angmax=self.angmax,
                   UseZmat=self.UseZmat,InitZmat=self.a.InitZmat,
                   zmat_id=self.a.zmat_id,zmat_index=self.a.zmat_index,
-                  dEstop=self.dEstop,nn=self.nn,vdwnn=self.vdwnn,
-                  learnpair=learnpair,beta=beta)
+                  dEstop=self.dEstop,dEtole=self.dEtole,nn=self.nn,vdwnn=self.vdwnn,
+                  learnpair=learnpair,beta=beta,groupi=groupi,groupj=groupj)
       if learnWay==2:
          Deformed,zmats,zv,zvlo,zvhi = irmd.opt()
       else:
@@ -552,9 +564,10 @@ class LearningMachine(object):
                     'colFrame':self.colFrame,
                     'UseZmat':self.UseZmat,
                     'freeatoms':self.freeatoms,
+                    'freepairs':self.freepairs,
                     'bore':self.bore,
                     'writelib':self.writelib}
-           js.dump(options,fj,sort_keys=True,indent=2)
+           js.dump(options,fj,sort_keys=True,indent=2) 
 
   def load_config(self):
       with open('options.json','r') as fj:
@@ -594,6 +607,7 @@ class LearningMachine(object):
            self.UseZmat      = options['UseZmat']
            self.bore         = options['bore']
            self.writelib     = options['writelib']
+           self.freepairs    = options['freepairs']
            if self.freeatoms!= options['freeatoms']:
               self.freeatoms = options['freeatoms']
               self.a.get_freebond(self.freeatoms)
