@@ -111,7 +111,7 @@ class IRFF_NP(object):
          self.be_layer = j['be_layer']
          self.vdw_layer= j['vdw_layer']
          rcut          = j['rcut']
-         rcuta         = j['rcutAngle']
+         rcuta         = j['rcutBond']
          lf.close()
          self.init_bonds()
       else:
