@@ -75,10 +75,11 @@ def freq(atoms=None):
     frequencies.write_jmol()
 
 
-def md(atoms=None,gen='poscar.gen',step=100,model='mpnn',initT=300,timeStep=0.1,
+def md(atoms=None,gen='poscar.gen',step=100,nn=True,ffield='ffield.json',initT=300,timeStep=0.1,
        vdwnn=False,print_interval=1):
     irmd = IRMD(time_step=timeStep,totstep=step,atoms=atoms,gen=gen,Tmax=10000,
-                ro=0.8,rmin=0.5,initT=initT,vdwnn=vdwnn,print_interval=print_interval)
+                ro=0.8,rmin=0.5,initT=initT,vdwnn=vdwnn,print_interval=print_interval,
+                nn=nn,ffield='ffield')
     irmd.run()
 
     irmd.close()
