@@ -1,11 +1,11 @@
 from __future__ import print_function
-import os
+from os import system
 import numpy as np
 from ase import Atoms
+from ase.io import read # ,write
 from ase.io.trajectory import TrajectoryWriter
 from ase.calculators.singlepoint import SinglePointCalculator
 import matplotlib.pyplot as plt
-# from ase import Atoms
 from ..molecule import press_mol
 
 
@@ -145,46 +145,60 @@ def change_keyword(lib='reaxff_rdx'):
     fin.close()
 
 
-def gulp_out_to_geo(natm=200,scale= 1.05,geo='gulp opt'):
-    system('cat his.xyz | tail -%s>>card.xyz' %str(natm+2))
+def get_md_results(out='gulp.out'):
+    ''' get the result from the  gulp MD simulation '''
+    flog = open(out,'r')
+    E,Epot,T,P = [],[],[],[]
 
-    # get lattice vector
-    fout = open('gulp.out','r')
-    lines = fout.readlines()
-    for i,line in enumerate(lines):
-        if line.find('Final Cartesian lattice vectors')>=0:
-           iline = i
-           break 
-    fout.close()
- 
-    v = []
-    for l in range(3):
-        line = lines[iline+l+2]
-        #print line
-        v.append([float(line.split()[0])*scale,float(line.split()[1])*scale,
-                float(line.split()[2])*scale])
-
-    system('cp card.xyz card.xyz.sample')
-
-    fs = open('card.xyz.sample','r')
-    fc = open('card.xyz','w')
-
-    for line in fs.readlines():
-        ls = line.split()
-        if len(ls)==4:
-           print(ls[0],float(ls[1])*scale,float(ls[2])*scale,float(ls[3])*scale, file=fc)
-        else:
-           print(line[:-1], file=fc)
-
-    fs.close()
-    fc.close()
-
-    emdk(cardtype='xyz',cardfile='card.xyz',
-         vec={'a':v[0],'b':v[1],'c':v[2]},
-         output=geo,center='.False.',log='log')
+    for line in flog.readlines():
+        l = line.split()
+        if line.find('Potential energy  (eV) =')>=0:
+           Epot.append(float(l[4]))
+        elif line.find('Temperature       (K)  =')>=0:
+           T.append(float(l[3]))
+        elif line.find('Total energy      (eV) =')>=0:
+           E.append(float(l[4]))
+        elif line.find('Pressure         (GPa) =')>=0:
+           P.append(float(l[3]))
+    flog.close()
+    return E,Epot,T,P
 
 
-def plot_gulp(log='gulp.out'):
+def plot_md(E,Epot,T,P,show=True):
+    plt.figure(figsize=(12,12))  
+
+    plt.subplot(2,2,1)  
+    plt.ylabel(r'$Total Energy (Unit: eV)$')
+    plt.xlabel(r'$Iterations$')
+    plt.plot(E,label=r'$Total Energy$', color='blue', linewidth=2)
+    plt.legend(loc='best',edgecolor='yellowgreen')
+
+    plt.subplot(2,2,2)  
+    plt.ylabel(r'$Potential Energy (Unit: eV)$')
+    plt.xlabel(r'$Iterations$')
+    plt.plot(Epot,label=r'$Potential Energy$', color='blue', linewidth=2)
+    plt.legend(loc='best',edgecolor='yellowgreen')
+
+    plt.subplot(2,2,3)  
+    plt.ylabel(r'$Temperature (Unit: K)$')
+    plt.xlabel(r'$Iterations$')
+    plt.plot(T,label=r'$Temperature$', color='blue', linewidth=2)
+    plt.legend(loc='best',edgecolor='yellowgreen')
+
+    plt.subplot(2,2,4)  
+    plt.ylabel(r'$Pressure (Unit: GPa)$')
+    plt.xlabel(r'$Iterations$')
+    plt.plot(P,label=r'$Pressure$', color='blue', linewidth=2)
+    plt.legend(loc='best',edgecolor='yellowgreen')
+
+    if show:
+       plt.show()
+    else:
+       plt.savefig('MD_results.svg') 
+    plt.close()
+
+
+def plot_optimize(log='gulp.out'):
     ''' plot the energies or other from gulp log file'''
     flog = open(log,'r')
     cyc,e = [],[]
@@ -199,8 +213,8 @@ def plot_gulp(log='gulp.out'):
     plt.figure()
     plt.ylabel(r'$Energy (Unit: eV)$')
     plt.xlabel(r'$Iterations$')
-    plt.xlim(6,500)
-    plt.ylim(-625,-600)
+    # plt.xlim(6,500)
+    # plt.ylim(-625,-600)
     plt.plot(cyc,e,label=r'$energy .VS. iterations$', color='blue', linewidth=2)
     plt.savefig('energy_vs_iteration.png') 
     plt.close()
@@ -279,3 +293,49 @@ def xyztotraj(fxyz,checkMol=False,mode='w',scale=True):
     his.close()
 
 
+def opt(T=350,gen='siesta.traj',mode='w'):
+    A = read(gen,index=-1)
+    A = press_mol(A)
+    write_gulp_in(A,runword='opti conv qiterative',
+                  T=T,
+                  lib='reax')
+    print('\n-  running gulp opt ...')
+    system('gulp<inp-gulp>gulp.out')
+    xyztotraj('his.xyz',mode='w')
+
+
+
+def optl(T=350,gen='poscar.gen',mc=500):
+    A = read(gen)
+    # A = press_mol(A)
+    write_gulp_in(A,runword='opti conp qiterative stre atomic_stress',
+                  T=T,maxcyc=mc,
+                  lib='reax')
+    print('\n-  running gulp optimize ...')
+    system('/home/feng/gulp/gulp-5.0/Src/gulp<inp-gulp>gulp.out')
+    xyztotraj('his.xyz',mode='w',scale=False)
+
+
+def npt(T=350,time_step=0.1,tot_step=10.0):
+    A = read('packed.gen')
+    write_gulp_in(A,runword='md conp qiterative',
+                  T=T,
+                  time_step=time_step,
+                  tot_step=tot_step,
+                  lib='reax')
+    system('gulp<inp-gulp>gulp.out')
+    xyztotraj('his.xyz')
+
+
+def nvt(atoms=None,gen='poscar.gen',T=350,time_step=0.1,tot_step=100,index=-1,mode='w',lib='reax'):
+    if atoms is None:
+       atoms = read(gen,index=index)
+    write_gulp_in(atoms,runword='md qiterative conv',
+                  T=T,
+                  time_step=time_step,
+                  tot_step=tot_step,
+                  lib=lib)
+    print('\n-  running gulp nvt ...')
+    system('gulp<inp-gulp>gulp.out')
+    xyztotraj('his.xyz',mode=mode)
+
